@@ -34,11 +34,13 @@ class ApiBase(object):
             res = requests.request(**req_args, timeout=60)
             res.raise_for_status() # Verifica se ocorreu algum erro HTTP
             return res
+        
         except (ConnectionError, ChunkedEncodingError) as e:
             logging.error(e)
             logging.error(f"Connection error occurred: {e}. Retrying {attempt + 1}/{max_retries}...")
             if attempt == max_retries - 1:
                 raise # Lança a exceção se o limite de tentativas for atingido
+            
         except requests.exceptions.RequestException as e:
             logging.error(e)
             logging.error(f"An error occurred: {e}")
@@ -87,31 +89,50 @@ class ApiBase(object):
       logging.info(req_args)
 
       res = self.__make_request(req_args)
+
+      res_data = None
+      try:
+        res_data = res.json()
+      except ValueError:
+        res_data = res.text
+    
+      logging.info(res_data)
       
       if res.status_code == 503:
         raise UnavailableException()
+      
       elif res.status_code == 404:
         raise  NotFoundException(res.content)
+      
       elif res.status_code == 409:
         raise ConflictException(res.content)
+      
       elif res.status_code == 401:
         raise UnauthorizedException(res.content)
+      
       elif res.status_code == 400:
-        raise BadRequestException(res.content)
+        raise BadRequestException(
+          message='Bad request from API',
+          response_body=res_data,
+          request_details=req_args
+        )
+      
       elif res.status_code != 200:
         raise Exception(res.content)
         
-      res = res.content.decode('utf-8')
-
       logging.info(f'{str(http_method).upper()} response:')
       logging.info(jsonpickle.encode(res))
       
-      return res
+      return res_data
+    
     except UnavailableException as e:
       raise e
-    except BadRequestException as e:
-        raise e
+    
     except NotFoundException as e:
         raise e
+    
+    except BadRequestException as e:
+        raise e
+    
     except Exception as e:
         raise e
\ No newline at end of file
